@@ -33,9 +33,10 @@
 #  define KITEMVIEWS_DEPRECATED_NO_EXPORT KITEMVIEWS_NO_EXPORT KITEMVIEWS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KITEMVIEWS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KITEMVIEWS_NO_DEPRECATED
+#    define KITEMVIEWS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
